Crate diverge
diverge
0.0.4
All Items
Crate Items
Macros
Crate
diverge
Macros

diverge
Aborts the outer function if given
Some
by returning its value, or continues the function if given
None
. This is particularly useful for understandable extension injection site specification.